==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkLocator.java <==
// java wrapper for vtkLocator object
//

package vtk;
import vtk.*;

public class vtkLocator extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataSet_2(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_2(id0); }

  private native long GetDataSet_3();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMaxLevel_4(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_4(id0); }

  private native int GetMaxLevelMinValue_5();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_5(); }

  private native int GetMaxLevelMaxValue_6();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_6(); }

  private native int GetMaxLevel_7();
  public int GetMaxLevel()
    { return GetMaxLevel_7(); }

  private native int GetLevel_8();
  public int GetLevel()
    { return GetLevel_8(); }

  private native void SetAutomatic_9(int id0);
  public void SetAutomatic(int id0)
    { SetAutomatic_9(id0); }

  private native int GetAutomatic_10();
  public int GetAutomatic()
    { return GetAutomatic_10(); }

  private native void AutomaticOn_11();
  public void AutomaticOn()
    { AutomaticOn_11(); }

  private native void AutomaticOff_12();
  public void AutomaticOff()
    { AutomaticOff_12(); }

  private native void SetTolerance_13(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_13(id0); }

  private native double GetToleranceMinValue_14();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_14(); }

  private native double GetToleranceMaxValue_15();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_15(); }

  private native double GetTolerance_16();
  public double GetTolerance()
    { return GetTolerance_16(); }

  private native void Update_17();
  public void Update()
    { Update_17(); }

  private native void Initialize_18();
  public void Initialize()
    { Initialize_18(); }

  private native void BuildLocator_19();
  public void BuildLocator()
    { BuildLocator_19(); }

  private native void FreeSearchStructure_20();
  public void FreeSearchStructure()
    { FreeSearchStructure_20(); }

  private native void GenerateRepresentation_21(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_21(id0,id1); }

  private native int GetBuildTime_22();
  public int GetBuildTime()
    { return GetBuildTime_22(); }

  private native void Register_23(vtkObjectBase id0);
  public void Register(vtkObjectBase id0)
    { Register_23(id0); }

  private native void UnRegister_24(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_24(id0); }

  public vtkLocator() { super(); }

  public vtkLocator(long id) { super(id); }

}

==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkLocator.java <==
// java wrapper for vtkLocator object
//

package vtk;
import vtk.*;

public class vtkLocator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetDataSet_2(vtkDataSet id0);
  public void SetDataSet(vtkDataSet id0)
    { SetDataSet_2(id0); }

  private native long GetDataSet_3();
  public vtkDataSet GetDataSet() {
    long temp = GetDataSet_3();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMaxLevel_4(int id0);
  public void SetMaxLevel(int id0)
    { SetMaxLevel_4(id0); }

  private native int GetMaxLevelMinValue_5();
  public int GetMaxLevelMinValue()
    { return GetMaxLevelMinValue_5(); }

  private native int GetMaxLevelMaxValue_6();
  public int GetMaxLevelMaxValue()
    { return GetMaxLevelMaxValue_6(); }

  private native int GetMaxLevel_7();
  public int GetMaxLevel()
    { return GetMaxLevel_7(); }

  private native int GetLevel_8();
  public int GetLevel()
    { return GetLevel_8(); }

  private native void SetAutomatic_9(int id0);
  public void SetAutomatic(int id0)
    { SetAutomatic_9(id0); }

  private native int GetAutomatic_10();
  public int GetAutomatic()
    { return GetAutomatic_10(); }

  private native void AutomaticOn_11();
  public void AutomaticOn()
    { AutomaticOn_11(); }

  private native void AutomaticOff_12();
  public void AutomaticOff()
    { AutomaticOff_12(); }

  private native void SetTolerance_13(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_13(id0); }

  private native double GetToleranceMinValue_14();
  public double GetToleranceMinValue()
    { return GetToleranceMinValue_14(); }

  private native double GetToleranceMaxValue_15();
  public double GetToleranceMaxValue()
    { return GetToleranceMaxValue_15(); }

  private native double GetTolerance_16();
  public double GetTolerance()
    { return GetTolerance_16(); }

  private native void Update_17();
  public void Update()
    { Update_17(); }

  private native void Initialize_18();
  public void Initialize()
    { Initialize_18(); }

  private native void BuildLocator_19();
  public void BuildLocator()
    { BuildLocator_19(); }

  private native void FreeSearchStructure_20();
  public void FreeSearchStructure()
    { FreeSearchStructure_20(); }

  private native void GenerateRepresentation_21(int id0,vtkPolyData id1);
  public void GenerateRepresentation(int id0,vtkPolyData id1)
    { GenerateRepresentation_21(id0,id1); }

  private native int GetBuildTime_22();
  public int GetBuildTime()
    { return GetBuildTime_22(); }

  private native void Register_23(vtkObjectBase id0);
  public void Register(vtkObjectBase id0)
    { Register_23(id0); }

  private native void UnRegister_24(vtkObjectBase id0);
  public void UnRegister(vtkObjectBase id0)
    { UnRegister_24(id0); }

  public vtkLocator() { super(); }

  public vtkLocator(long id) { super(id); }

}
